@@ -1,6 +1,6 @@
 import logging
 import warnings
-from typing import Any, List
+from typing import List
 
 import numpy as np
 
