@@ -4,6 +4,7 @@ logger = logging.getLogger(__name__)
 from typing import List
 
 from . import SizeDistributionBaseModel as PSDBase
+from .GaudinMeloy import GaudinMeloy
 from .GGSSizeDistributionModel import GGS
 from .LogNormalSizeDistributionModel import LogNormal
 from .RRBSizeDistributionModel import RRB
@@ -11,7 +12,7 @@ from .SigmoidSizeDistributionModel import Sigmoid
 
 
 def getPSDModelsList() -> List[PSDBase.SizeDistributionBaseModel]:
-    return [RRB(), GGS(), LogNormal(), Sigmoid()]
+    return [RRB(), GGS(), LogNormal(), Sigmoid(), GaudinMeloy()]
 
 
 m: PSDBase.SizeDistributionBaseModel
